# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.initial_permissions import InitialPermissions

class TestInitialPermissions(unittest.TestCase):
    """InitialPermissions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InitialPermissions:
        """Test InitialPermissions
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InitialPermissions`
        """
        model = InitialPermissions()
        if include_optional:
            return InitialPermissions(
                pk = 56,
                name = '',
                mode = 'user',
                role = '',
                permissions = [
                    56
                    ],
                permissions_obj = [
                    authentik_client.models.permission.Permission(
                        id = 56, 
                        name = '', 
                        codename = '', 
                        model = '', 
                        app_label = '', 
                        app_label_verbose = '', 
                        model_verbose = '', )
                    ]
            )
        else:
            return InitialPermissions(
                pk = 56,
                name = '',
                mode = 'user',
                role = '',
                permissions_obj = [
                    authentik_client.models.permission.Permission(
                        id = 56, 
                        name = '', 
                        codename = '', 
                        model = '', 
                        app_label = '', 
                        app_label_verbose = '', 
                        model_verbose = '', )
                    ],
        )
        """

    def testInitialPermissions(self):
        """Test InitialPermissions"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
